@@ -88,7 +88,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In__set_sin_addr(SPVM_ENV* env, SPVM_VALUE*
   void* obj_address = stack[1].oval;
   
   if (!obj_address) {
-    return env->die_v2(env, stack, "The address must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in_addr* address = env->get_pointer(env, stack, obj_address);
